==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/catnip/levelWrappers/SchematicChunkSource.java <==
package com.zurrtum.create.catnip.levelWrappers;

import org.jetbrains.annotations.Nullable;

import java.util.Collection;
import java.util.List;
import java.util.function.BooleanSupplier;
import net.minecraft.class_10286;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1508;
import net.minecraft.class_1657;
import net.minecraft.class_1845;
import net.minecraft.class_1923;
import net.minecraft.class_1937;
import net.minecraft.class_1959;
import net.minecraft.class_22;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2394;
import net.minecraft.class_243;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_269;
import net.minecraft.class_2791;
import net.minecraft.class_2802;
import net.minecraft.class_2806;
import net.minecraft.class_2818;
import net.minecraft.class_2874;
import net.minecraft.class_3194;
import net.minecraft.class_3414;
import net.minecraft.class_3419;
import net.minecraft.class_3568;
import net.minecraft.class_3610;
import net.minecraft.class_3611;
import net.minecraft.class_3612;
import net.minecraft.class_5269;
import net.minecraft.class_5321;
import net.minecraft.class_5362;
import net.minecraft.class_5455;
import net.minecraft.class_5577;
import net.minecraft.class_5712;
import net.minecraft.class_6754;
import net.minecraft.class_6756;
import net.minecraft.class_6880;
import net.minecraft.class_7699;
import net.minecraft.class_8921;
import net.minecraft.class_9209;
import net.minecraft.class_9895;

public class SchematicChunkSource extends class_2802 {
    private final class_1937 fallbackWorld;

    public SchematicChunkSource(class_1937 world) {
        fallbackWorld = world;
    }

    @Nullable
    @Override
    public class_2791 method_12246(int x, int z) {
        return new EmptierChunk(fallbackWorld);
    }

    @Override
    public class_1937 method_16399() {
        return fallbackWorld;
    }

    @Nullable
    @Override
    public class_2791 method_12121(int x, int z, class_2806 status, boolean p_212849_4_) {
        return method_12246(x, z);
    }

    @Override
    public String method_12122() {
        return "WrappedChunkProvider";
    }

    @Override
    public class_3568 method_12130() {
        return fallbackWorld.method_22336();
    }

    @Override
    public void method_12127(BooleanSupplier p_202162_, boolean p_202163_) {
    }

    @Override
    public int method_14151() {
        return 0;
    }

    public static class EmptierChunk extends class_2818 {

        private static final class DummyLevel extends class_1937 {
            private DummyLevel(
                class_5269 pLevelData,
                class_5321<class_1937> pDimension,
                class_5455 pRegistryAccess,
                class_6880<class_2874> pDimensionTypeRegistration,
                boolean pIsClientSide,
                boolean pIsDebug,
                long pBiomeZoomSeed,
                int pMaxChainedNeighborUpdates
            ) {
                super(
                    pLevelData,
                    pDimension,
                    pRegistryAccess,
                    pDimensionTypeRegistration,
                    pIsClientSide,
                    pIsDebug,
                    pBiomeZoomSeed,
                    pMaxChainedNeighborUpdates
                );
                access = pRegistryAccess;
            }

            private final class_5455 access;

            private DummyLevel(class_1937 level) {
                this(null, null, level.method_30349(), level.method_40134(), false, false, 0, 0);
            }

            @Override
            public class_2802 method_8398() {
                return null;
            }

            @Override
            public void method_8444(class_1297 pPlayer, int pType, class_2338 pPos, int pData) {
            }

            @Override
            public void method_43275(@Nullable class_1297 entity, class_6880<class_5712> gameEvent, class_243 pos) {
            }

            @Override
            public void method_32888(class_6880<class_5712> holder, class_243 vec3, class_5712.class_7397 context) {
            }

            @Override
            public class_5455 method_30349() {
                return access;
            }

            @Override
            public class_1845 method_59547() {
                return null;
            }

            @Override
            public class_9895 method_61269() {
                return null;
            }

            @Override
            public List<? extends class_1657> method_18456() {
                return null;
            }

            @Override
            public class_6880<class_1959> method_22387(int pX, int pY, int pZ) {
                return null;
            }

            @Override
            public int method_8615() {
                return 63;
            }

            @Override
            public float method_24852(class_2350 pDirection, boolean pShade) {
                return 0;
            }

            @Override
            public void method_8413(class_2338 pPos, class_2680 pOldState, class_2680 pNewState, int pFlags) {
            }

            @Override
            public void method_43128(
                class_1297 pPlayer,
                double pX,
                double pY,
                double pZ,
                class_3414 pSound,
                class_3419 pCategory,
                float pVolume,
                float pPitch
            ) {
            }

            @Override
            public void method_43129(class_1297 pPlayer, class_1297 pEntity, class_3414 pEvent, class_3419 pCategory, float pVolume, float pPitch) {
            }

            @Override
            public void method_8454(
                @Nullable class_1297 entity,
                @Nullable class_1282 damageSource,
                @Nullable class_5362 behavior,
                double x,
                double y,
                double z,
                float power,
                boolean createFire,
                class_7867 explosionSourceType,
                class_2394 smallParticle,
                class_2394 largeParticle,
                class_6880<class_3414> soundEvent
            ) {
            }

            @Override
            public void method_8465(
                class_1297 pPlayer,
                double pX,
                double pY,
                double pZ,
                class_6880<class_3414> pSound,
                class_3419 pSource,
                float pVolume,
                float pPitch,
                long pSeed
            ) {
            }

            @Override
            public void method_47967(
                class_1297 p_220363_,
                double p_220364_,
                double p_220365_,
                double p_220366_,
                class_3414 p_220367_,
                class_3419 p_220368_,
                float p_220369_,
                float p_220370_,
                long p_220371_
            ) {
            }

            @Override
            public void method_8449(
                class_1297 p_220372_,
                class_1297 p_220373_,
                class_6880<class_3414> p_220374_,
                class_3419 p_220375_,
                float p_220376_,
                float p_220377_,
                long p_220378_
            ) {
            }

            @Override
            public String method_31419() {
                return null;
            }

            @Override
            public class_1297 method_8469(int pId) {
                return null;
            }

            @Override
            public Collection<class_1508> method_65097() {
                return List.of();
            }

            @Nullable
            @Override
            public class_22 method_17891(class_9209 mapId) {
                return null;
            }

            @Override
            public void method_8517(int pBreakerId, class_2338 pPos, int pProgress) {
            }

            @Override
            public class_269 method_8428() {
                return null;
            }

            @Override
            public class_10286 method_8433() {
                return null;
            }

            @Override
            public class_5577<class_1297> method_31592() {
                return null;
            }

            @Override
            public class_6756<class_2248> method_8397() {
                return class_6754.method_39362();
            }

            @Override
            public class_6756<class_3611> method_8405() {
                return class_6754.method_39362();
            }

            @Override
            public class_7699 method_45162() {
                return class_7699.method_45397();
            }

            @Override
            public class_8921 method_54719() {
                return null;
            }
        }

        public EmptierChunk(class_1937 level) {
            super(new DummyLevel(level), class_1923.field_35107);
        }

        @Override
        public class_2680 method_8320(class_2338 p_180495_1_) {
            return class_2246.field_10243.method_9564();
        }

        @Nullable
        public class_2680 setBlockState(class_2338 p_177436_1_, class_2680 p_177436_2_, boolean p_177436_3_) {
            return null;
        }

        @Override
        public class_3610 method_8316(class_2338 p_204610_1_) {
            return class_3612.field_15906.method_15785();
        }

        @Override
        public int method_8317(class_2338 p_217298_1_) {
            return 0;
        }

        @Nullable
        public class_2586 method_12201(class_2338 p_177424_1_, class_2819 p_177424_2_) {
            return null;
        }

        @Override
        public void method_12216(class_2586 p_150813_1_) {
        }

        @Override
        public void method_12007(class_2586 p_177426_2_) {
        }

        @Override
        public void method_12041(class_2338 p_177425_1_) {
        }

        public void markUnsaved() {
        }

        @Override
        public boolean method_12223() {
            return true;
        }

        @Override
        public boolean method_12228(int p_76606_1_, int p_76606_2_) {
            return true;
        }

        @Override
        public class_3194 method_12225() {
            return class_3194.field_44855;
        }
    }
}

==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/catnip/levelWrappers/SchematicChunkSource.java <==
package com.zurrtum.create.catnip.levelWrappers;

import org.jetbrains.annotations.Nullable;

import java.util.Collection;
import java.util.List;
import java.util.function.BooleanSupplier;
import net.minecraft.class_10286;
import net.minecraft.class_11749;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1508;
import net.minecraft.class_1657;
import net.minecraft.class_1845;
import net.minecraft.class_1923;
import net.minecraft.class_1937;
import net.minecraft.class_1959;
import net.minecraft.class_22;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2394;
import net.minecraft.class_243;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_269;
import net.minecraft.class_2784;
import net.minecraft.class_2791;
import net.minecraft.class_2802;
import net.minecraft.class_2806;
import net.minecraft.class_2818;
import net.minecraft.class_2874;
import net.minecraft.class_3194;
import net.minecraft.class_3414;
import net.minecraft.class_3419;
import net.minecraft.class_3568;
import net.minecraft.class_3610;
import net.minecraft.class_3611;
import net.minecraft.class_3612;
import net.minecraft.class_5217;
import net.minecraft.class_5269;
import net.minecraft.class_5321;
import net.minecraft.class_5362;
import net.minecraft.class_5455;
import net.minecraft.class_5577;
import net.minecraft.class_5712;
import net.minecraft.class_6012;
import net.minecraft.class_6754;
import net.minecraft.class_6756;
import net.minecraft.class_6880;
import net.minecraft.class_7699;
import net.minecraft.class_8921;
import net.minecraft.class_9209;
import net.minecraft.class_9895;

public class SchematicChunkSource extends class_2802 {
    private final class_1937 fallbackWorld;

    public SchematicChunkSource(class_1937 world) {
        fallbackWorld = world;
    }

    @Nullable
    @Override
    public class_2791 method_12246(int x, int z) {
        return new EmptierChunk(fallbackWorld);
    }

    @Override
    public class_1937 method_16399() {
        return fallbackWorld;
    }

    @Nullable
    @Override
    public class_2791 method_12121(int x, int z, class_2806 status, boolean p_212849_4_) {
        return method_12246(x, z);
    }

    @Override
    public String method_12122() {
        return "WrappedChunkProvider";
    }

    @Override
    public class_3568 method_12130() {
        return fallbackWorld.method_22336();
    }

    @Override
    public void method_12127(BooleanSupplier p_202162_, boolean p_202163_) {
    }

    @Override
    public int method_14151() {
        return 0;
    }

    public static class EmptierChunk extends class_2818 {

        private static final class DummyLevel extends class_1937 {
            private DummyLevel(
                class_5269 pLevelData,
                class_5321<class_1937> pDimension,
                class_5455 pRegistryAccess,
                class_6880<class_2874> pDimensionTypeRegistration,
                boolean pIsClientSide,
                boolean pIsDebug,
                long pBiomeZoomSeed,
                int pMaxChainedNeighborUpdates
            ) {
                super(
                    pLevelData,
                    pDimension,
                    pRegistryAccess,
                    pDimensionTypeRegistration,
                    pIsClientSide,
                    pIsDebug,
                    pBiomeZoomSeed,
                    pMaxChainedNeighborUpdates
                );
                access = pRegistryAccess;
            }

            private final class_5455 access;
            private final class_2784 border = new class_2784();

            private DummyLevel(class_1937 level) {
                this(null, null, level.method_30349(), level.method_40134(), false, false, 0, 0);
            }

            @Override
            public void method_27873(class_5217.class_12064 spawnPoint) {
            }

            @Override
            public class_5217.class_12064 method_74854() {
                return field_9232.method_74893();
            }

            @Override
            public class_2784 method_8621() {
                return border;
            }

            @Override
            public class_2802 method_8398() {
                return null;
            }

            @Override
            public void method_8444(class_1297 pPlayer, int pType, class_2338 pPos, int pData) {
            }

            @Override
            public void method_43275(@Nullable class_1297 entity, class_6880<class_5712> gameEvent, class_243 pos) {
            }

            @Override
            public void method_32888(class_6880<class_5712> holder, class_243 vec3, class_5712.class_7397 context) {
            }

            @Override
            public class_5455 method_30349() {
                return access;
            }

            @Override
            public class_1845 method_59547() {
                return null;
            }

            @Override
            public class_9895 method_61269() {
                return null;
            }

            @Override
            public List<? extends class_1657> method_18456() {
                return null;
            }

            @Override
            public class_6880<class_1959> method_22387(int pX, int pY, int pZ) {
                return null;
            }

            @Override
            public int method_8615() {
                return 63;
            }

            @Override
            public float method_24852(class_2350 pDirection, boolean pShade) {
                return 0;
            }

            @Override
            public void method_8413(class_2338 pPos, class_2680 pOldState, class_2680 pNewState, int pFlags) {
            }

            @Override
            public void method_43128(
                class_1297 pPlayer,
                double pX,
                double pY,
                double pZ,
                class_3414 pSound,
                class_3419 pCategory,
                float pVolume,
                float pPitch
            ) {
            }

            @Override
            public void method_43129(class_1297 pPlayer, class_1297 pEntity, class_3414 pEvent, class_3419 pCategory, float pVolume, float pPitch) {
            }

            @Override
            public void method_8454(
                @Nullable class_1297 entity,
                @Nullable class_1282 damageSource,
                @Nullable class_5362 behavior,
                double x,
                double y,
                double z,
                float power,
                boolean createFire,
                class_7867 explosionSourceType,
                class_2394 smallParticle,
                class_2394 largeParticle,
                class_6012<class_11749> blockParticles,
                class_6880<class_3414> soundEvent
            ) {
            }

            @Override
            public void method_8465(
                class_1297 pPlayer,
                double pX,
                double pY,
                double pZ,
                class_6880<class_3414> pSound,
                class_3419 pSource,
                float pVolume,
                float pPitch,
                long pSeed
            ) {
            }

            @Override
            public void method_47967(
                class_1297 p_220363_,
                double p_220364_,
                double p_220365_,
                double p_220366_,
                class_3414 p_220367_,
                class_3419 p_220368_,
                float p_220369_,
                float p_220370_,
                long p_220371_
            ) {
            }

            @Override
            public void method_8449(
                class_1297 p_220372_,
                class_1297 p_220373_,
                class_6880<class_3414> p_220374_,
                class_3419 p_220375_,
                float p_220376_,
                float p_220377_,
                long p_220378_
            ) {
            }

            @Override
            public String method_31419() {
                return null;
            }

            @Override
            public class_1297 method_8469(int pId) {
                return null;
            }

            @Override
            public Collection<class_1508> method_65097() {
                return List.of();
            }

            @Nullable
            @Override
            public class_22 method_17891(class_9209 mapId) {
                return null;
            }

            @Override
            public void method_8517(int pBreakerId, class_2338 pPos, int pProgress) {
            }

            @Override
            public class_269 method_8428() {
                return null;
            }

            @Override
            public class_10286 method_8433() {
                return null;
            }

            @Override
            public class_5577<class_1297> method_31592() {
                return null;
            }

            @Override
            public class_6756<class_2248> method_8397() {
                return class_6754.method_39362();
            }

            @Override
            public class_6756<class_3611> method_8405() {
                return class_6754.method_39362();
            }

            @Override
            public class_7699 method_45162() {
                return class_7699.method_45397();
            }

            @Override
            public class_8921 method_54719() {
                return null;
            }
        }

        public EmptierChunk(class_1937 level) {
            super(new DummyLevel(level), class_1923.field_35107);
        }

        @Override
        public class_2680 method_8320(class_2338 p_180495_1_) {
            return class_2246.field_10243.method_9564();
        }

        @Nullable
        public class_2680 setBlockState(class_2338 p_177436_1_, class_2680 p_177436_2_, boolean p_177436_3_) {
            return null;
        }

        @Override
        public class_3610 method_8316(class_2338 p_204610_1_) {
            return class_3612.field_15906.method_15785();
        }

        @Override
        public int method_8317(class_2338 p_217298_1_) {
            return 0;
        }

        @Nullable
        public class_2586 method_12201(class_2338 p_177424_1_, class_2819 p_177424_2_) {
            return null;
        }

        @Override
        public void method_12216(class_2586 p_150813_1_) {
        }

        @Override
        public void method_12007(class_2586 p_177426_2_) {
        }

        @Override
        public void method_12041(class_2338 p_177425_1_) {
        }

        public void markUnsaved() {
        }

        @Override
        public boolean method_12223() {
            return true;
        }

        @Override
        public boolean method_12228(int p_76606_1_, int p_76606_2_) {
            return true;
        }

        @Override
        public class_3194 method_12225() {
            return class_3194.field_44855;
        }
    }
}
